Credits
=======

Original development
----------------

 - Xi Jin <fate_stigma@hotmail.com>

Ontoviz packaging and further development
------------

 - René Fritze <rene.fritze@wwu.de>
 - Christian Himpe <christian.himpe@wwu.de>
